==> thux.price-1.0.0.tar.gz: thux.price-1.0.0/thux/price/admin.py <==
# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _

from jmb.jadmin.options import JumboModelAdmin

from . import models


class PriceListAdmin(JumboModelAdmin):
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',),
        }),
        (_('visualization admin'), {
            'fields': ('ordering',),
            'classes': ('collapse',),
        }),
        (_('general admin'), {'fields': ('status', 'name', 'slug', 'code', 'price_list_type', 'currency')}),
        (_('date admin'), {'fields': (('date_begin', 'date_end',),)}),
    )
    list_display = (
        'get_status_icon', 'code', 'name',
        'date_begin', 'date_end', 'ordering',
        'get_edit_icon', 'get_delete_icon'
    )
    search_fields = ('name', 'code')
    prepopulated_fields = {'slug': ('name',)}


class PriceListItemAdmin(JumboModelAdmin):
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',),
        }),
        (_('visualization admin'), {
            'fields': ('ordering',),
            'classes': ('collapse',),
        }),
        (_('general admin'), {'fields': (
            'status', 'price_list', 'product', 'price',
            'vat', 'price_tax_included',
            'discount1', 'discount2', 'recharge',
            'min_quantity', 'max_quantity',
        )}),
    )
    list_display = (
        'get_status_icon', 'get_price_list', 'product',
        'price', 'vat', 'price_tax_included',
        'discount1', 'discount2', 'recharge',
        'min_quantity', 'max_quantity',
        'get_edit_icon', 'get_delete_icon'
    )
    list_display_csv = (
        'status', 'get_price_list_csv', 'product',
        'get_date_begin', 'get_date_end', 'price',
        'vat', 'price_tax_included',
        'discount1', 'discount2', 'recharge',
        'min_quantity', 'max_quantity'
    )
    search_fields = ('product__name', 'product__code')

    def get_price_list_csv(self, obj):
        return "{} - {}".format(
            obj.price_list.code, obj.price_list.name
        )
    get_price_list_csv.short_description = _('price list')

    def get_price_list(self, obj):
        return "{}<br/><b>{}</b><br/>{} - {}".format(
            obj.price_list.code, obj.price_list.name,
            obj.price_list.date_begin, obj.price_list.date_end
        )
    get_price_list.short_description = _("price list")
    get_price_list.admin_order_field = 'price_list.name'
    get_price_list.allow_tags = True


class OrganizationPriceListAdmin(JumboModelAdmin):
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',),
        }),
        (_('general admin'), {
            'fields': (
                'status', 'price_list', 'organization', 'discount1', 'discount2', 'recharge',
            ),
        }),
    )
    search_fields = ('organization__code', 'organization__name',)
    list_display = (
        'get_status_icon', 'get_organization_code', 'get_organization_name',
        'get_price_list_code', 'get_price_list_name', 'discount1', 'discount2', 'recharge',
        'get_edit_icon', 'get_delete_icon'
    )

    def get_organization_code(self, obj):
        return obj.organization.code
    get_organization_code.short_description = _('organization code')
    get_organization_code.admin_order_field = 'organization.code'
    get_organization_code.allow_tags = True

    def get_organization_name(self, obj):
        return obj.organization.name
    get_organization_name.short_description = _('organization name')
    get_organization_name.admin_order_field = 'organization.name'
    get_organization_name.allow_tags = True

    def get_price_list_code(self, obj):
        return obj.price_list.code
    get_price_list_code.short_description = _('price list code')
    get_price_list_code.admin_order_field = 'price_list.code'
    get_price_list_code.allow_tags = True

    def get_price_list_name(self, obj):
        return obj.price_list.name
    get_price_list_name.short_description = _('price list name')
    get_price_list_name.admin_order_field = 'price_list.name'
    get_price_list_name.allow_tags = True

admin.site.register(models.PriceList, PriceListAdmin)
admin.site.register(models.PriceListItem, PriceListItemAdmin)
admin.site.register(models.OrganizationPriceList, OrganizationPriceListAdmin)

==> thux.price-2.0.1.tar.gz: thux.price-2.0.1/thux/price/admin.py <==
# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _

from . import models


class PriceListAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {'fields': (
            'code', 'name', 'slug',
            'price_list_type', 'currency'
        )}),
        (_('date admin'), {'fields': (('date_begin', 'date_end',),)}),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'code', 'name',
        'date_begin', 'date_end', 'ordering',
    )
    search_fields = ('name', 'code')
    prepopulated_fields = {'slug': ('name',)}
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class PriceListItemAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {'fields': (
            'price_list', 'product', 'price',
            'vat', 'price_tax_included',
            'discount1', 'discount2', 'recharge',
            'min_quantity', 'max_quantity',
        )}),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'get_price_list_code', 'product',
        'price', 'vat', 'price_tax_included',
        'discount1', 'discount2', 'recharge',
        'min_quantity', 'max_quantity',
    )
    search_fields = ('product__name', 'product__code')
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)

    def get_price_list_code(self, obj):
        return obj.price_list.code
    get_price_list_code.short_description = _("PLC")
    get_price_list_code.admin_order_field = 'price_list.code'


class OrganizationPriceListAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': (
                'price_list', 'organization', 'discount1', 'discount2', 'recharge',
            ),
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    search_fields = ('organization__code', 'organization__name',)
    list_display = (
        'status', 'get_organization_code', 'get_organization_name',
        'get_price_list_code', 'get_price_list_name',
        'discount1', 'discount2', 'recharge',
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)

    def get_organization_code(self, obj):
        return obj.organization.code
    get_organization_code.short_description = _('organization code')
    get_organization_code.admin_order_field = 'organization.code'
    get_organization_code.allow_tags = True

    def get_organization_name(self, obj):
        return obj.organization.name
    get_organization_name.short_description = _('organization name')
    get_organization_name.admin_order_field = 'organization.name'
    get_organization_name.allow_tags = True

    def get_price_list_code(self, obj):
        return obj.price_list.code
    get_price_list_code.short_description = _('price list code')
    get_price_list_code.admin_order_field = 'price_list.code'
    get_price_list_code.allow_tags = True

    def get_price_list_name(self, obj):
        return obj.price_list.name
    get_price_list_name.short_description = _('price list name')
    get_price_list_name.admin_order_field = 'price_list.name'
    get_price_list_name.allow_tags = True


admin.site.register(models.PriceList, PriceListAdmin)
admin.site.register(models.PriceListItem, PriceListItemAdmin)
admin.site.register(models.OrganizationPriceList, OrganizationPriceListAdmin)
